@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """ Tests for the Simple cache class
-
-$Id$
 """
 
 import unittest
@@ -21,10 +19,10 @@ from dataflake.cache.tests.base import CacheTestCase
 
 try:
     unicode
-except NameError: #pragma NO COVER Python3
-    unicode = str #pragma NO COVER Python3
+except NameError:  # pragma NO COVER Python3
+    unicode = str  # pragma NO COVER Python3
+
 
-       
 class TestSimpleCache(CacheTestCase):
 
     def _getTargetClass(self):
@@ -55,18 +53,16 @@ class TestSimpleCache(CacheTestCase):
         self.cache.set('key2', 'value2')
         self.assertEqual(set(self.cache.keys()), set(['key1', 'key2']))
         self.assertEqual(set(self.cache.values()), set(['value1', 'value2']))
-        self.assertEqual( set(self.cache.items())
-                         , set([('key1', 'value1'), ('key2', 'value2')])
-                         )
+        self.assertEqual(set(self.cache.items()),
+                         set([('key1', 'value1'), ('key2', 'value2')]))
         self.assertEqual(self.cache.get('key2'), 'value2')
 
         self.cache.set('key3', 'value3')
         self.cache.invalidate('key1')
         self.assertEqual(set(self.cache.keys()), set(['key2', 'key3']))
         self.assertEqual(set(self.cache.values()), set(['value2', 'value3']))
-        self.assertEqual( set(self.cache.items())
-                         , set([('key2', 'value2'), ('key3', 'value3')])
-                         )
+        self.assertEqual(set(self.cache.items()),
+                         set([('key2', 'value2'), ('key3', 'value3')]))
         self.assertFalse(self.cache.get('key1'))
 
         self.cache.set('key3', 'NEW')
@@ -75,9 +71,8 @@ class TestSimpleCache(CacheTestCase):
         self.cache.invalidate('UNKNOWN')
         self.assertEqual(set(self.cache.keys()), set(['key2', 'key3']))
         self.assertEqual(set(self.cache.values()), set(['value2', 'NEW']))
-        self.assertEqual( set(self.cache.items())
-                         , set([('key2', 'value2'), ('key3', 'NEW')])
-                         )
+        self.assertEqual(set(self.cache.items()),
+                         set([('key2', 'value2'), ('key3', 'NEW')]))
 
         self.cache.invalidate()
         self.assertFalse(list(self.cache.keys()))
@@ -88,55 +83,42 @@ class TestSimpleCache(CacheTestCase):
         self.cache.set(unicode('key1'), unicode('value1'))
         self.assertEqual(list(self.cache.keys()), [unicode('key1')])
         self.assertEqual(list(self.cache.values()), [unicode('value1')])
-        self.assertEqual( list(self.cache.items())
-                        , [(unicode('key1'), unicode('value1'))]
-                        )
+        self.assertEqual(list(self.cache.items()),
+                         [(unicode('key1'), unicode('value1'))])
         self.assertEqual(self.cache.get(unicode('key1')), unicode('value1'))
 
         self.cache.set(unicode('key2'), unicode('value2'))
-        self.assertEqual( set(self.cache.keys())
-                        , set([unicode('key1'), unicode('key2')])
-                        )
-        self.assertEqual( set(self.cache.values())
-                        , set([unicode('value1'), unicode('value2')])
-                        )
-        self.assertEqual( set(self.cache.items())
-                         , set([ (unicode('key1'), unicode('value1'))
-                               , (unicode('key2'), unicode('value2'))
-                               ])
-                         )
+        self.assertEqual(set(self.cache.keys()),
+                         set([unicode('key1'), unicode('key2')]))
+        self.assertEqual(set(self.cache.values()),
+                         set([unicode('value1'), unicode('value2')]))
+        self.assertEqual(set(self.cache.items()),
+                         set([(unicode('key1'), unicode('value1')),
+                              (unicode('key2'), unicode('value2'))]))
         self.assertEqual(self.cache.get(unicode('key2')), unicode('value2'))
 
         self.cache.set(unicode('key3'), unicode('value3'))
         self.cache.invalidate(unicode('key1'))
-        self.assertEqual( set(self.cache.keys())
-                        , set([unicode('key2'), unicode('key3')])
-                        )
-        self.assertEqual( set(self.cache.values())
-                        , set([unicode('value2'), unicode('value3')])
-                        )
-        self.assertEqual( set(self.cache.items())
-                         , set([ (unicode('key2'), unicode('value2'))
-                               , (unicode('key3'), unicode('value3'))
-                               ])
-                         )
+        self.assertEqual(set(self.cache.keys()),
+                         set([unicode('key2'), unicode('key3')]))
+        self.assertEqual(set(self.cache.values()),
+                         set([unicode('value2'), unicode('value3')]))
+        self.assertEqual(set(self.cache.items()),
+                         set([(unicode('key2'), unicode('value2')),
+                              (unicode('key3'), unicode('value3'))]))
         self.assertFalse(self.cache.get(unicode('key1')))
 
         self.cache.set(unicode('key3'), unicode('NEW'))
         self.assertEqual(self.cache.get(unicode('key3')), unicode('NEW'))
 
         self.cache.invalidate(unicode('UNKNOWN'))
-        self.assertEqual( set(self.cache.keys())
-                        , set([unicode('key2'), unicode('key3')])
-                        )
-        self.assertEqual( set(self.cache.values())
-                        , set([unicode('value2'), unicode('NEW')])
-                        )
-        self.assertEqual( set(self.cache.items())
-                         , set([ (unicode('key2'), unicode('value2'))
-                               , (unicode('key3'), unicode('NEW'))
-                               ])
-                         )
+        self.assertEqual(set(self.cache.keys()),
+                         set([unicode('key2'), unicode('key3')]))
+        self.assertEqual(set(self.cache.values()),
+                         set([unicode('value2'), unicode('NEW')]))
+        self.assertEqual(set(self.cache.items()),
+                         set([(unicode('key2'), unicode('value2')),
+                              (unicode('key3'), unicode('NEW'))]))
 
         self.cache.invalidate()
         self.assertFalse(list(self.cache.keys()))
@@ -159,18 +141,16 @@ class TestSimpleCache(CacheTestCase):
         self.cache.set(key2, value2)
         self.assertEqual(set(self.cache.keys()), set([key1, key2]))
         self.assertEqual(set(self.cache.values()), set([value1, value2]))
-        self.assertEqual( set(self.cache.items())
-                         , set([(key1, value1), (key2, value2)])
-                         )
+        self.assertEqual(set(self.cache.items()),
+                         set([(key1, value1), (key2, value2)]))
         self.assertEqual(self.cache.get(key2), value2)
 
         self.cache.set(key3, value3)
         self.cache.invalidate(key1)
         self.assertEqual(set(self.cache.keys()), set([key2, key3]))
         self.assertEqual(set(self.cache.values()), set([value2, value3]))
-        self.assertEqual( set(self.cache.items())
-                         , set([(key2, value2), (key3, value3)])
-                         )
+        self.assertEqual(set(self.cache.items()),
+                         set([(key2, value2), (key3, value3)]))
         self.assertFalse(self.cache.get(key1))
 
         self.cache.set(key3, 'NEW')
@@ -179,9 +159,8 @@ class TestSimpleCache(CacheTestCase):
         self.cache.invalidate('UNKNOWN')
         self.assertEqual(set(self.cache.keys()), set([key2, key3]))
         self.assertEqual(set(self.cache.values()), set([value2, 'NEW']))
-        self.assertEqual( set(self.cache.items())
-                         , set([(key2, value2), (key3, 'NEW')])
-                         )
+        self.assertEqual(set(self.cache.items()),
+                         set([(key2, value2), (key3, 'NEW')]))
 
         self.cache.invalidate()
         self.assertFalse(list(self.cache.keys()))
@@ -212,4 +191,3 @@ def test_suite():
         unittest.makeSuite(TestSimpleCache),
         unittest.makeSuite(TestLockingSimpleCache),
         ))
-
